Index: wp-content/themes/twentyfourteen/inc/customizer.php
===================================================================
--- wp-content/themes/twentyfourteen/inc/customizer.php	(revision 26369)
+++ wp-content/themes/twentyfourteen/inc/customizer.php	(working copy)
@@ -38,7 +38,7 @@
 	add_filter( 'theme_mod_accent_light', 'twentyfourteen_accent_light' );
 
 	// Add the featured content section in case it's not already there.
-	$wp_customize->add_section( 'featured_content', array(
+	$wp_customize->add_section( 'twentyfourteen_featured_content', array(
 		'title'       => __( 'Featured Content', 'twentyfourteen' ),
 		'description' => sprintf( __( 'Use a <a href="%1$s"> tag</a> to feature your posts. If no posts match the tag, <a href="%2$s">sticky posts</a> will be displayed instead.', 'twentyfourteen' ), admin_url( '/edit.php?tag=featured' ), admin_url( '/edit.php?show_sticky=1' ) ),
 		'priority'    => 130,
@@ -51,7 +51,7 @@
 
 	$wp_customize->add_control( 'featured_content_layout', array(
 		'label'   => __( 'Layout', 'twentyfourteen' ),
-		'section' => 'featured_content',
+		'section' => 'twentyfourteen_featured_content',
 		'type'    => 'select',
 		'choices' => array(
 			'grid'   => __( 'Grid',   'twentyfourteen' ),
Index: wp-content/themes/twentyfourteen/functions.php
===================================================================
--- wp-content/themes/twentyfourteen/functions.php	(revision 26369)
+++ wp-content/themes/twentyfourteen/functions.php	(working copy)
@@ -105,7 +105,7 @@
 	) ) );
 
 	// Add support for featured content.
-	add_theme_support( 'featured-content', array(
+	add_theme_support( 'twentyfourteen-featured-content', array(
 		'featured_content_filter' => 'twentyfourteen_get_featured_posts',
 		'max_posts' => 6,
 	) );
@@ -495,9 +495,9 @@
 /*
  * Add Featured Content functionality.
  *
  * To overwrite in a plugin, define your own Featured_Content class on or
  * before the 'setup_theme' hook.
  */
-if ( ! class_exists( 'Featured_Content' ) && 'plugins.php' !== $GLOBALS['pagenow'] ) {
+if ( ! class_exists( 'Twenty_Fourteen_Featured_Content' ) && 'plugins.php' !== $GLOBALS['pagenow'] ) {
 	require get_template_directory() . '/inc/featured-content.php';
 }
@@ -495,9 +495,9 @@
  * Add Featured Content functionality.
  *
- * To overwrite in a plugin, define your own Featured_Content class on or
+ * To overwrite in a plugin, define your own Twenty_Fourteen_Featured_Content class on or
  * before the 'setup_theme' hook.
  */
Index: wp-content/themes/twentyfourteen/inc/featured-content.php
===================================================================
--- wp-content/themes/twentyfourteen/inc/featured-content.php	(revision 26369)
+++ wp-content/themes/twentyfourteen/inc/featured-content.php	(working copy)
@@ -10,15 +10,15 @@
  * has special meaning beyond that of a normal tags, users will have the
  * ability to hide it from the front-end of their site.
  */
-class Featured_Content {
+class Twenty_Fourteen_Featured_Content {
 
 	/**
 	 * The maximum number of posts that a Featured Content area can contain. We
 	 * define a default value here but themes can override this by defining a
 	 * "max_posts" entry in the second parameter passed in the call to
-	 * add_theme_support( 'featured-content' ).
+	 * add_theme_support( 'twentyfourteen-featured-content' ).
 	 *
-	 * @see Featured_Content::init()
+	 * @see Twenty_Fourteen_Featured_Content::init()
 	 */
 	public static $max_posts = 15;
 
@@ -35,15 +35,15 @@
 	 * Conditionally hook into WordPress
 	 *
 	 * Theme must declare that they support this module by adding
-	 * add_theme_support( 'featured-content' ); during after_setup_theme.
+	 * add_theme_support( 'twentyfourteen-featured-content' ); during after_setup_theme.
 	 *
 	 * If no theme support is found there is no need to hook into WordPress.
 	 * We'll just return early instead.
 	 *
-	 * @uses Featured_Content::$max_posts
+	 * @uses Twenty_Fourteen_Featured_Content::$max_posts
 	 */
 	public static function init() {
-		$theme_support = get_theme_support( 'featured-content' );
+		$theme_support = get_theme_support( 'twentyfourteen-featured-content' );
 
 		// Return early if theme does not support Featured Content.
 		if ( ! $theme_support ) {
@@ -96,7 +96,7 @@
 	/**
 	 * Get featured posts
 	 *
-	 * @uses Featured_Content::get_featured_post_ids()
+	 * @uses Twenty_Fourteen_Featured_Content::get_featured_post_ids()
 	 *
 	 * @return array
 	 */
@@ -122,13 +122,13 @@
 	 * This function will return the an array containing the
 	 * post IDs of all featured posts.
 	 *
 	 * Sets the "featured_content_ids" transient.
 	 *
 	 * @return array Array of post IDs
 	 */
 	public static function get_featured_post_ids() {
 		// Return array of cached results if they exist.
-		$featured_ids = get_transient( 'featured_content_ids' );
+		$featured_ids = get_transient( 'twentyfourteen_featured_content_ids' );
 		if ( ! empty( $featured_ids ) ) {
 			return array_map( 'absint', (array) $featured_ids );
 		}
@@ -164,7 +164,7 @@
 		$featured_ids = wp_list_pluck( (array) $featured, 'ID' );
 		$featured_ids = array_map( 'absint', $featured_ids );
 
-		set_transient( 'featured_content_ids', $featured_ids );
+		set_transient( 'twentyfourteen_featured_content_ids', $featured_ids );
 
 		return $featured_ids;
 	}
@@ -183,10 +183,10 @@
 	 * Delete transient
 	 *
 	 * Hooks in the "save_post" action.
-	 * @see Featured_Content::validate_settings().
+	 * @see Twenty_Fourteen_Featured_Content::validate_settings().
 	 */
 	public static function delete_transient() {
-		delete_transient( 'featured_content_ids' );
+		delete_transient( 'twentyfourteen_featured_content_ids' );
 	}
 
 	/**
@@ -196,7 +196,7 @@
 	 * onto the 'pre_get_posts' action, this changes the parameters of the query
 	 * before it gets any posts.
 	 *
-	 * @uses Featured_Content::get_featured_post_ids();
+	 * @uses Twenty_Fourteen_Featured_Content::get_featured_post_ids();
 	 * @param WP_Query $query
 	 * @return WP_Query Possibly modified WP_Query
 	 */
@@ -237,10 +237,10 @@
 	 *
 	 * It's important to mention that the transient needs to be deleted, too.
 	 * While it may not be obvious by looking at the function alone, the transient
 	 * is deleted by Featured_Content::validate_settings().
 	 *
 	 * Hooks in the "delete_post_tag" action.
-	 * @see Featured_Content::validate_settings().
+	 * @see Twenty_Fourteen_Featured_Content::validate_settings().
 	 *
 	 * @param int $tag_id The term_id of the tag that has been deleted.
 	 * @return void
@@ -254,7 +254,7 @@
 
 		$settings['tag-id'] = 0;
 		$settings = self::validate_settings( $settings );
-		update_option( 'featured-content', $settings );
+		update_option( 'twentyfourteen-featured-content', $settings );
 	}
 
 	/**
@@ -266,7 +266,7 @@
 	 * @param array $taxonomies An array of taxonomy slugs.
 	 * @return array $terms
 	 *
-	 * @uses Featured_Content::get_setting()
+	 * @uses Twenty_Fourteen_Featured_Content::get_setting()
 	 */
 	public static function hide_featured_term( $terms, $taxonomies ) {
 
@@ -304,7 +304,7 @@
 	 * @param array $taxonomy An array of taxonomy slugs.
 	 * @return array $terms
 	 *
-	 * @uses Featured_Content::get_setting()
+	 * @uses Twenty_Fourteen_Featured_Content::get_setting()
 	 */
 	public static function hide_the_featured_term( $terms, $id, $taxonomy ) {
 
@@ -335,13 +335,13 @@
 	/**
 	 * Register custom setting on the Settings -> Reading screen
 	 *
-	 * @uses Featured_Content::render_form()
-	 * @uses Featured_Content::validate_settings()
+	 * @uses Twenty_Fourteen_Featured_Content::render_form()
+	 * @uses Twenty_Fourteen_Featured_Content::validate_settings()
 	 *
 	 * @return void
 	 */
 	public static function register_setting() {
-		register_setting( 'featured-content', 'featured-content', array( __CLASS__, 'validate_settings' ) );
+		register_setting( 'twentyfourteen-featured-content', 'twentyfourteen-featured-content', array( __CLASS__, 'validate_settings' ) );
 	}
 
 	/**
@@ -350,34 +350,34 @@
 	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 	 */
 	public static function customize_register( $wp_customize ) {
-		$wp_customize->add_section( 'featured_content', array(
+		$wp_customize->add_section( 'twentyfourteen_featured_content', array(
 			'title'          => __( 'Featured Content', 'twentyfourteen' ),
 			'description'    => sprintf( __( 'Use the <a href="%1$s">"featured" tag</a> to feature your posts. You can change this to a tag of your choice; if no posts match the tag, <a href="%2$s">sticky posts</a> will be displayed instead.', 'twentyfourteen' ), admin_url( '/edit.php?tag=featured' ), admin_url( '/edit.php?show_sticky=1' ) ),
 			'priority'       => 130,
-			'theme_supports' => 'featured-content',
+			'theme_supports' => 'twentyfourteen-featured-content',
 		) );
 
 		// Add Featured Content settings.
-		$wp_customize->add_setting( 'featured-content[tag-name]', array(
+		$wp_customize->add_setting( 'twentyfourteen-featured-content[tag-name]', array(
 			'default'              => 'featured',
 			'type'                 => 'option',
 			'sanitize_js_callback' => array( __CLASS__, 'delete_transient' ),
 		) );
-		$wp_customize->add_setting( 'featured-content[hide-tag]', array(
+		$wp_customize->add_setting( 'twentyfourteen-featured-content[hide-tag]', array(
 			'default'              => true,
 			'type'                 => 'option',
 			'sanitize_js_callback' => array( __CLASS__, 'delete_transient' ),
 		) );
 
 		// Add Featured Content controls.
-		$wp_customize->add_control( 'featured-content[tag-name]', array(
+		$wp_customize->add_control( 'twentyfourteen-featured-content[tag-name]', array(
 			'label'    => __( 'Tag Name', 'twentyfourteen' ),
-			'section'  => 'featured_content',
+			'section'  => 'twentyfourteen_featured_content',
 			'priority' => 20,
 		) );
-		$wp_customize->add_control( 'featured-content[hide-tag]', array(
+		$wp_customize->add_control( 'twentyfourteen-featured-content[hide-tag]', array(
 			'label'    => __( 'Don&rsquo;t display tag on front end.', 'twentyfourteen' ),
-			'section'  => 'featured_content',
+			'section'  => 'twentyfourteen_featured_content',
 			'type'     => 'checkbox',
 			'priority' => 30,
 		) );
@@ -389,7 +389,7 @@
 	 * @since Twenty Fourteen 1.0
 	 */
 	public static function enqueue_scripts() {
-		wp_enqueue_script( 'featured-content-suggest', get_template_directory_uri() . '/js/featured-content-admin.js', array( 'jquery', 'suggest' ), '20131022', true );
+		wp_enqueue_script( 'twentyfourteen-featured-content-suggest', get_template_directory_uri() . '/js/featured-content-admin.js', array( 'jquery', 'suggest' ), '20131022', true );
 	}
 
 	/**
@@ -402,13 +402,13 @@
 	 * In the event that you only require one setting, you may pass its name
 	 * as the first parameter to the function and only that value will be returned.
 	 *
-	 * @uses Featured_Content::sanitize_quantity()
+	 * @uses Twenty_Fourteen_Featured_Content::sanitize_quantity()
 	 *
 	 * @param string $key The key of a recognized setting.
 	 * @return mixed Array of all settings by default. A single value if passed as first parameter.
 	 */
 	public static function get_setting( $key = 'all' ) {
-		$saved = (array) get_option( 'featured-content' );
+		$saved = (array) get_option( 'twentyfourteen-featured-content' );
 
 		$defaults = array(
 			'hide-tag' => 1,
@@ -434,10 +434,10 @@
 	 * Make sure that all user supplied content is in an
 	 * expected format before saving to the database. This
 	 * function will also delete the transient set in
-	 * Featured_Content::get_featured_content().
+	 * Twenty_Fourteen_Featured_Content::get_featured_content().
 	 *
-	 * @uses Featured_Content::self::sanitize_quantity()
-	 * @uses Featured_Content::self::delete_transient()
+	 * @uses Twenty_Fourteen_Featured_Content::self::sanitize_quantity()
+	 * @uses Twenty_Fourteen_Featured_Content::self::delete_transient()
 	 *
 	 * @param array $input
 	 * @return array $output
@@ -480,7 +480,7 @@
 	 * @param int $input The value to sanitize.
 	 * @return int A number between 1 and FeaturedContent::$max_posts.
 	 *
-	 * @uses Featured_Content::$max_posts
+	 * @uses Twenty_Fourteen_Featured_Content::$max_posts
 	 */
 	public static function sanitize_quantity( $input ) {
 		$quantity = absint( $input );
@@ -495,4 +495,4 @@
 	}
 }
 
-Featured_Content::setup();
+Twenty_Fourteen_Featured_Content::setup();
\ No newline at end of file
@@ -122,13 +122,13 @@
 	 * post IDs of all featured posts.
 	 *
-	 * Sets the "featured_content_ids" transient.
+	 * Sets the "twentyfourteen_featured_content_ids" transient.
 	 *
 	 * @return array Array of post IDs
@@ -237,10 +237,10 @@
 	 * It's important to mention that the transient needs to be deleted, too.
 	 * While it may not be obvious by looking at the function alone, the transient
-	 * is deleted by Featured_Content::validate_settings().
+	 * is deleted by Twenty_Fourteen_Featured_Content::validate_settings().
 	 *
 	 * Hooks in the "delete_post_tag" action.
